==> buildfile_1.0.0_for_2.1_src.zip: org.vivianj.eclipse.plugin.buildfile/src/org/vivianj/eclipse/plugin/buildfile/util/BuildFileContent.java <==
/*
 * 2004-10-23 Фݼ 
 */
package org.vivianj.eclipse.plugin.buildfile.util;

import org.eclipse.jface.text.IDocument;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeItem;
import org.eclipse.ui.editors.text.TextEditor;
import org.vivianj.eclipse.plugin.buildfile.data.Data;

/**
 * BuildFileContent  Tree ڵ,buildfile
 */
public class BuildFileContent {
	private Tree tree = null;

	private TextEditor editor = null;

	/**
	 * BuildFileContent 
	 *  
	 */
	public BuildFileContent() {
	}

	/**
	 * BuildFileContent 
	 * 
	 * @param p_tree
	 *            buildfile
	 */
	public BuildFileContent(Tree p_tree) {
		this.tree = p_tree;
	}

	/**
	 * BuildFileContent 
	 * 
	 * @param p_editor
	 *            ITextEditorʵ
	 */
	public BuildFileContent(TextEditor p_editor) {
		this.editor = p_editor;
	}

	/**
	 * BuildFileContent 
	 * 
	 * @param p_tree
	 *            buildfile
	 * @param p_editor
	 *            ITextEditorʵ
	 */
	public BuildFileContent(Tree p_tree, TextEditor p_editor) {
		this.tree = p_tree;
		this.editor = p_editor;
	}

	public Tree getTree() {
		return tree;
	}

	public void setTree(Tree tree) {
		this.tree = tree;
	}

	public TextEditor getEditor() {
		return editor;
	}

	public void setEditor(TextEditor editor) {
		this.editor = editor;
	}

	/**
	 * ProjectɶӦbuildfieļ
	 * 
	 * @return buildfieļ
	 */
	private String getBuildFileContent() {
		String result = "";
		StringBuffer buffer = new StringBuffer(result);
		//ȡProjectԪضӦڵ
		TreeItem treeItem = this.tree.getTopItem();
		//ȡProjectԪصıǩ
		buffer.append(this.getOpenElement(treeItem, 0));

		//ȡProjectӦTargetԪضӦıǩ
		buffer.append(this.getContent(treeItem, 1));

		//ȡProjectԪصĹرձǩ
		buffer.append(this.getCloseElement(treeItem, 0));
		result = buffer.toString();
		return result;
	}

	/**
	 * ڵ,buildfileǩ
	 * 
	 * @param treeItem -
	 *            ȡݵTreeڵ
	 * @param depth -
	 *            ڵȣھɵǰelementҪٿոʾbuildfile
	 * @return treeItem ڵ㼰ӽڵӦԪ
	 */
	private String getContent(TreeItem treeItem, int depth) {
		String result = "";
		StringBuffer buffer = new StringBuffer(result);
		//TreeItemֱӽڵ,ɶӦ
		TreeItem[] subTreeItem = treeItem.getItems();
		TreeItem currentTreeItem = null;
		for (int i = 0; i < subTreeItem.length; i++) {
			currentTreeItem = subTreeItem[i];
			//ȡTreeItemڵӦıǩ
			buffer.append(this.getOpenElement(currentTreeItem, depth));
			// TODO ˴--ڹ--ɸTreeItemֱӽڵӦ
			buffer.append(this.getContent(currentTreeItem, depth + 1));

			//ȡTreeItemڵӦĹرձǩ
			buffer.append(this.getCloseElement(currentTreeItem, depth));
		}

		result = buffer.toString();
		return result;
	}

	/**
	 * getOpenElement ȡָTreeItemڵӦıǩ
	 * 
	 * @param treeItem -
	 *            ȡݵTreeڵ
	 * @param depth -
	 *            ڵȣھɵǰelementҪٿոʾbuildfile
	 * @return ָTreeItemڵӦıǩ
	 */
	private String getOpenElement(TreeItem treeItem, int depth) {
		String result = "";
		for (int i = 0; i < depth; i++) {
			result = result + "  ";
		}
		Data data = (Data) treeItem.getData();
		result = result + data.getOpenElement() + "\r\n";
		return result;
	}

	/**
	 * getOpenElement ȡָTreeItemڵӦĹرձǩ
	 * 
	 * @param treeItem -
	 *            ȡݵTreeڵ
	 * @param depth -
	 *            ڵȣھɵǰelementҪٿոʾbuildfile
	 * @return ָTreeItemڵӦıǩ
	 */
	private String getCloseElement(TreeItem treeItem, int depth) {
		String result = "";
		for (int i = 0; i < depth; i++) {
			result = result + "  ";
		}
		Data data = (Data) treeItem.getData();
		result = result + data.getCloseElement() + "\r\n";
		return result;
	}

	/**
	 * refreshContent ȡɵbuildfile ҽݷTextEditorؼ
	 */
	public void refreshContent() {
		IDocument document = editor.getDocumentProvider().getDocument(
				editor.getEditorInput());
		String content = this.getBuildFileContent();

		document.set(content);
	}
}

==> buildfile_1.2.36_for_3.0_src.zip: org.vivianj.eclipse.plugin.buildfile/src/org/vivianj/eclipse/plugin/buildfile/util/BuildFileContent.java <==
/*
 * 2004-10-23 Фݼ 
 */
package org.vivianj.eclipse.plugin.buildfile.util;

import org.eclipse.jface.text.IDocument;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeItem;
import org.eclipse.ui.editors.text.TextEditor;
import org.vivianj.eclipse.plugin.buildfile.data.NodeData;

/**
 * BuildFileContent  Tree ڵ,buildfile
 */
public class BuildFileContent {
	private Tree tree = null;

	private TextEditor editor = null;

	/**
	 * BuildFileContent 
	 *  
	 */
	public BuildFileContent() {
	}

	/**
	 * BuildFileContent 
	 * 
	 * @param p_tree
	 *            buildfile
	 */
	public BuildFileContent(Tree p_tree) {
		this.tree = p_tree;
	}

	/**
	 * BuildFileContent 
	 * 
	 * @param p_editor
	 *            ITextEditorʵ
	 */
	public BuildFileContent(TextEditor p_editor) {
		this.editor = p_editor;
	}

	/**
	 * BuildFileContent 
	 * 
	 * @param p_tree
	 *            buildfile
	 * @param p_editor
	 *            ITextEditorʵ
	 */
	public BuildFileContent(Tree p_tree, TextEditor p_editor) {
		this.tree = p_tree;
		this.editor = p_editor;
	}

	public Tree getTree() {
		return tree;
	}

	public void setTree(Tree tree) {
		this.tree = tree;
	}

	public TextEditor getEditor() {
		return editor;
	}

	public void setEditor(TextEditor editor) {
		this.editor = editor;
	}

	/**
	 * ProjectɶӦbuildfieļ
	 * 
	 * @return buildfieļ
	 */
	private String getBuildFileContent() {
		String result = "";
		StringBuffer buffer = new StringBuffer(result);
		//ȡProjectԪضӦڵ
		TreeItem treeItem = this.tree.getTopItem();
		//ȡProjectԪصıǩ
		buffer.append(this.getOpenElement(treeItem, 0));

		//ȡProjectӦTargetԪضӦıǩ
		buffer.append(this.getProjectContent(treeItem, 1));

		//ȡProjectԪصĹرձǩ
		buffer.append(this.getCloseElement(treeItem, 0));
		result = buffer.toString();
		return result;
	}

	/**
	 * ڵ,buildfileǩ
	 * 
	 * @param treeItem -
	 *            ȡݵTreeڵ
	 * @param depth -
	 *            ڵȣھɵǰelementҪٿոʾbuildfile
	 * @return treeItem ڵ㼰ӽڵӦԪ
	 */
	private String getContent(TreeItem treeItem, int depth) {
		String result = "";
		StringBuffer buffer = new StringBuffer(result);
		//TreeItemֱӽڵ,ɶӦ
		TreeItem[] subTreeItem = treeItem.getItems();
		TreeItem currentTreeItem = null;
		for (int i = 0; i < subTreeItem.length; i++) {
			currentTreeItem = subTreeItem[i];
			if (currentTreeItem.isDisposed() == false) {
				//ȡTreeItemڵӦıǩ
				buffer.append(this.getOpenElement(currentTreeItem, depth));
				// ڹɸTreeItemֱӽڵӦ
				buffer.append(this.getContent(currentTreeItem, depth + 1));

				//ȡTreeItemڵӦĹرձǩ
				buffer.append(this.getCloseElement(currentTreeItem, depth));
			}
		}

		result = buffer.toString();
		return result;
	}

	/**
	 * ڵ,buildfileǩ
	 * 
	 * @param treeItem -
	 *            ȡݵTreeڵ
	 * @param depth -
	 *            ڵȣھɵǰelementҪٿոʾbuildfile
	 * @return treeItem ڵ㼰ӽڵӦԪ
	 */
	private String getProjectContent(TreeItem treeItem, int depth) {
		String result = "";
		StringBuffer buffer = new StringBuffer(result);
		//TreeItemֱӽڵ,ɶӦ
		TreeItem[] subTreeItem = treeItem.getItems();
		TreeItem currentTreeItem = null;
		for (int i = 0; i < subTreeItem.length; i++) {
			currentTreeItem = subTreeItem[i];
			NodeData data = (NodeData) currentTreeItem.getData();
			if (data.getPath().trim().equals("project,property")) {
				//ȡTreeItemڵӦıǩ
				buffer.append(this.getOpenElement(currentTreeItem, depth));
				// ڹɸTreeItemֱӽڵӦ
				buffer.append(this.getContent(currentTreeItem, depth + 1));

				//ȡTreeItemڵӦĹرձǩ
				buffer.append(this.getCloseElement(currentTreeItem, depth));
			}
		}

		for (int i = 0; i < subTreeItem.length; i++) {
			currentTreeItem = subTreeItem[i];
			NodeData data = (NodeData) currentTreeItem.getData();
			if (!(data.getPath().trim().equals("project,property"))) {
				//ȡTreeItemڵӦıǩ
				buffer.append(this.getOpenElement(currentTreeItem, depth));
				// ڹɸTreeItemֱӽڵӦ
				buffer.append(this.getContent(currentTreeItem, depth + 1));

				//ȡTreeItemڵӦĹرձǩ
				buffer.append(this.getCloseElement(currentTreeItem, depth));
			}
		}

		result = buffer.toString();
		return result;
	}

	/**
	 * getOpenElement ȡָTreeItemڵӦıǩ
	 * 
	 * @param treeItem -
	 *            ȡݵTreeڵ
	 * @param depth -
	 *            ڵȣھɵǰelementҪٿոʾbuildfile
	 * @return ָTreeItemڵӦıǩ
	 */
	private String getOpenElement(TreeItem treeItem, int depth) {
		String result = "";
		for (int i = 0; i < depth; i++) {
			result = result + "  ";
		}
		NodeData data = (NodeData) treeItem.getData();
		result = result + data.getOpenElement() + "\r\n";
		return result;
	}

	/**
	 * getOpenElement ȡָTreeItemڵӦĹرձǩ
	 * 
	 * @param treeItem -
	 *            ȡݵTreeڵ
	 * @param depth -
	 *            ڵȣھɵǰelementҪٿոʾbuildfile
	 * @return ָTreeItemڵӦıǩ
	 */
	private String getCloseElement(TreeItem treeItem, int depth) {
		String result = "";
		for (int i = 0; i < depth; i++) {
			result = result + "  ";
		}
		NodeData data = (NodeData) treeItem.getData();
		result = result + data.getCloseElement() + "\r\n";
		return result;
	}

	/**
	 * refreshContent ȡɵbuildfile ҽݷTextEditorؼ
	 */
	public void refreshContent() {
		IDocument document = editor.getDocumentProvider().getDocument(
				editor.getEditorInput());
		String content = this.getBuildFileContent();

		document.set(content);
	}
}
